@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use strict;
 use warnings;
@@ -106,7 +106,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -128,12 +128,12 @@ of an C<E A D G B E> tuned guitar.
 
 Here is a handy diagram of MIDI pitch numbers laid out on a guitar neck:
 <br>
-<img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/master/guitar-position-midi-numbers.png">
+<img src="https://github.com/ology/MIDI-Chord-Guitar/blob/main/guitar-position-midi-numbers.png">
 <br>
 
 And here is a diagram of MIDI pitch octaves laid out on a guitar neck:
 <br>
-<img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/master/guitar-position-midi-octaves.png">
+<img src="https://github.com/ology/MIDI-Chord-Guitar/blob/main/guitar-position-midi-octaves.png">
 <br>
 
 =end html
